package
module
Version:
v0.0.0-...-7a1d936
Opens a new window with list of versions in this module.
Published: Dec 21, 2019
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func (q *Queue) Pop() interface{}
func (q *Queue) Push(data interface{})
Source Files
¶
Click to show internal directories.
Click to hide internal directories.